pub enum MessageClass {
Class0,
Class1,
Class2,
Class3,
}Message class
TODO clarify the difference to MessageType
displayed without being saved
stored on the SIM as memory is available, 99% this is what you want
message contains SIM card data, trigger response to the service center
Returns the "default value" for a type. Read more
This method tests for self and other values to be equal, and is used by ==. Read more
This method tests for !=.
Formats the value using the given formatter. Read more
Convert an i64 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
Convert an u64 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
Convert an isize to return an optional value of this type. If the value cannot be represented by this value, then None is returned. Read more
Convert an i8 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
Convert an i16 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
Convert an i32 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
Convert an i128 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
Convert a usize to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
Convert an u8 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
Convert an u16 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
Convert an u32 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
Convert an u128 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
Convert a f32 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
Convert a f64 to return an optional value of this type. If the type cannot be represented by this value, then None is returned. Read more
Serialize this value into the given Serde serializer. Read more
Deserialize this value from the given Serde deserializer. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static
Compare self to key and return true if they are equal.