[−][src]Enum messagebird_async::sms::PayloadType
SMS message type enum
Determines the type of the message payload
Variants
Smsregular text SMS, encoding defined by PayloadEncoding
Binaryraw binary encoding of bytes, some providers are incapable of handling those with their base stations, be warned
Flashpriority notification style SMS, there is no guarantee that this is stored on the phone
Methods
impl PayloadType[src]
impl PayloadTypeTrait Implementations
impl Eq for PayloadType[src]
impl Eq for PayloadTypeimpl PartialEq<PayloadType> for PayloadType[src]
impl PartialEq<PayloadType> for PayloadTypefn eq(&self, other: &PayloadType) -> bool | [src] |
| 1.0.0 [src] |
This method tests for !=.
impl ToString for PayloadType[src]
impl ToString for PayloadTypeimpl Clone for PayloadType[src]
impl Clone for PayloadTypefn clone(&self) -> PayloadType | [src] |
fn clone_from(&mut self, source: &Self) | 1.0.0 [src] |
Performs copy-assignment from source. Read more
impl Debug for PayloadType[src]
impl Debug for PayloadTypeimpl FromStr for PayloadType[src]
impl FromStr for PayloadTypetype Err = MessageBirdError
The associated error which can be returned from parsing.
fn from_str(s: &str) -> Result<Self, Self::Err> | [src] |
impl Serialize for PayloadType[src]
impl Serialize for PayloadTypefn serialize<__S>(&self, __serializer: __S) -> Result<__S::Ok, __S::Error> where | [src] |
impl<'de> Deserialize<'de> for PayloadType[src]
impl<'de> Deserialize<'de> for PayloadTypefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where | [src] |