[][src]Enum messagebird_async::sms::QueryRecipient

pub enum QueryRecipient {
    Group(Group),
    Msisdn(Msisdn),
}

recpient for sending a message

Differs from the message format, such that it will serialize to a string and can also be a group

Variants

Group(Group)Msisdn(Msisdn)