[][src]Struct messagebird_async::sms::list::Builder

pub struct Builder(_);

Methods

impl Builder
[src]

pub fn with_origin(self, originator: Originator) -> Self
[src]

Filters for the origin of the message

May be either a phone number, contact (unimplemented as of now) or a string. Messages which are sent via the API and do not have an origin defined will have "inbox" be the default originator.

pub fn with_payload_type(self, payload_type: PayloadType) -> Self
[src]

Filters for the payload type, either being SMS or Binary

pub fn with_direction(self, direction: Direction) -> Self
[src]

Filters for the direction

pub fn with_status(self, status: Status) -> Self
[src]

Filters for the status of the messages being listed

pub fn with_destination<T>(self, msisdn: T) -> Self where
    T: Into<QueryRecipient>, 
[src]

Counterpart to with_origin

pub fn skip(self, skip: u32) -> Self
[src]

The number of messages to skip before listing. Allows it to be used as paginating.

pub fn count(self, upper_limit: u32) -> Self
[src]

Limits the number of returned messages

pub fn contains_term(self, term: &str) -> Self
[src]

Validate the message contained a fixed term

pub fn between(self, start: DateTime, stop: DateTime) -> Self
[src]

Filters for messages that were sent in a certain range

pub fn from(self, start: DateTime) -> Self
[src]

Defines the timspan since when the message was sent TODO rename, too amibiguous

pub fn until(self, stop: DateTime) -> Self
[src]

Until what timestamp the messages we are interested in are filtered

pub fn build(self) -> ListParameters
[src]

Finalizes and returns the ListParameters