[−][src]Struct messagebird_async::sms::Identifier
Unique message identifier
Consists 32 alphanumeric characters (may change!)
Generate by the MessageBird backend on posting the message.
Methods
impl Identifier[src]
impl IdentifierTrait Implementations
impl Eq for Identifier[src]
impl Eq for Identifierimpl Default for Identifier[src]
impl Default for Identifierimpl PartialEq<Identifier> for Identifier[src]
impl PartialEq<Identifier> for Identifierfn eq(&self, other: &Identifier) -> bool | [src] |
fn ne(&self, other: &Identifier) -> bool | [src] |
impl Debug for Identifier[src]
impl Debug for Identifierimpl Display for Identifier[src]
impl Display for Identifierimpl Hash for Identifier[src]
impl Hash for Identifierfn hash<__H: Hasher>(&self, state: &mut __H) | [src] |
fn hash_slice<H>(data: &[Self], state: &mut H) where | 1.3.0 [src] |
Feeds a slice of this type into the given [Hasher]. Read more
impl FromStr for Identifier[src]
impl FromStr for Identifiertype Err = MessageBirdError
The associated error which can be returned from parsing.
fn from_str(s: &str) -> Result<Self, Self::Err> | [src] |
impl Serialize for Identifier[src]
impl Serialize for Identifierimpl<'de> Deserialize<'de> for Identifier[src]
impl<'de> Deserialize<'de> for Identifierfn deserialize<D>(deserializer: D) -> Result<Self, D::Error> where | [src] |