[−][src]Struct messagebird_async::sms::Recipient
Recipient
Definition of a recepient, used for querying the status of a SMS. Contains the deliver status of a message as well as the time of posting the SMS to the MessageBird API.
Methods
impl Recipient[src]
impl RecipientTrait Implementations
impl From<u64> for Recipient[src]
impl From<u64> for Recipientimpl From<Recipient> for QueryRecipient[src]
impl From<Recipient> for QueryRecipientimpl Eq for Recipient[src]
impl Eq for Recipientimpl PartialEq<Recipient> for Recipient[src]
impl PartialEq<Recipient> for Recipientimpl Clone for Recipient[src]
impl Clone for Recipientfn clone(&self) -> Recipient | [src] |
fn clone_from(&mut self, source: &Self) | 1.0.0 [src] |
Performs copy-assignment from source. Read more
impl Debug for Recipient[src]
impl Debug for Recipientimpl FromStr for Recipient[src]
impl FromStr for Recipienttype Err = MessageBirdError
The associated error which can be returned from parsing.
fn from_str(s: &str) -> Result<Self, Self::Err> | [src] |
impl Serialize for Recipient[src]
impl Serialize for Recipientfn serialize<__S>(&self, __serializer: __S) -> Result<__S::Ok, __S::Error> where | [src] |
impl<'de> Deserialize<'de> for Recipient[src]
impl<'de> Deserialize<'de> for Recipientfn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where | [src] |