1.0.0[−][src]Trait messagebird_async::sms::ToString
A trait for converting a value to a String.
This trait is automatically implemented for any type which implements the
Display trait. As such, ToString shouldn't be implemented directly:
Display should be implemented instead, and you get the ToString
implementation for free.
Required methods
fn to_string(&self) -> String
Converts the given value to a String.
Examples
Basic usage:
let i = 5; let five = String::from("5"); assert_eq!(five, i.to_string());
Implementations on Foreign Types
impl<'a> ToString for Cow<'a, str>[src]
impl<'a> ToString for Cow<'a, str>impl ToString for str[src]
impl ToString for strimpl ToString for String[src]
Loading content...
impl ToString for StringImplementors
impl ToString for Direction[src]
impl ToString for Directionimpl ToString for Originator[src]
impl ToString for Originatorimpl ToString for PayloadType[src]
impl ToString for PayloadTypeimpl ToString for QueryRecipient[src]
impl ToString for QueryRecipientimpl ToString for Status[src]
impl ToString for Statusimpl ToString for Gateway[src]
impl ToString for Gatewayimpl ToString for Msisdn[src]
impl ToString for Msisdnimpl<T> ToString for T where
T: Display + ?Sized, [src]
impl<T> ToString for T where
T: Display + ?Sized, Panics
In this implementation, the to_string method panics
if the Display implementation returns an error.
This indicates an incorrect Display implementation
since fmt::Write for String never returns an error itself.