[−][src]Enum messagebird_async::sms::QueryRecipient
recpient for sending a message
Differs from the message format, such that it will serialize to a string and can also be a group
Variants
Group(Group)Msisdn(Msisdn)Trait Implementations
impl From<Recipient> for QueryRecipient[src]
impl From<Recipient> for QueryRecipientimpl From<Msisdn> for QueryRecipient[src]
impl From<Msisdn> for QueryRecipientimpl From<Group> for QueryRecipient[src]
impl From<Group> for QueryRecipientimpl Eq for QueryRecipient[src]
impl Eq for QueryRecipientimpl PartialEq<QueryRecipient> for QueryRecipient[src]
impl PartialEq<QueryRecipient> for QueryRecipientfn eq(&self, other: &QueryRecipient) -> bool | [src] |
fn ne(&self, other: &QueryRecipient) -> bool | [src] |
impl ToString for QueryRecipient[src]
impl ToString for QueryRecipientimpl Clone for QueryRecipient[src]
impl Clone for QueryRecipientfn clone(&self) -> QueryRecipient | [src] |
fn clone_from(&mut self, source: &Self) | 1.0.0 [src] |
Performs copy-assignment from source. Read more
impl Debug for QueryRecipient[src]
impl Debug for QueryRecipientimpl FromStr for QueryRecipient[src]
impl FromStr for QueryRecipienttype Err = MessageBirdError
The associated error which can be returned from parsing.
fn from_str(_s: &str) -> Result<Self, Self::Err> | [src] |
impl Serialize for QueryRecipient[src]
impl Serialize for QueryRecipientAuto Trait Implementations
impl Send for QueryRecipient
impl Send for QueryRecipientimpl Sync for QueryRecipient
impl Sync for QueryRecipientBlanket Implementations
impl<T> From for T[src]
impl<T> From for Timpl<T, U> Into for T where
U: From<T>, [src]
impl<T, U> Into for T where
U: From<T>, impl<T> ToOwned for T where
T: Clone, [src]
impl<T> ToOwned for T where
T: Clone, impl<T> ToString for T where
T: Display + ?Sized, [src]
impl<T> ToString for T where
T: Display + ?Sized, impl<T, U> TryFrom for T where
T: From<U>, [src]
impl<T, U> TryFrom for T where
T: From<U>, type Error = !
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error> | [src] |
impl<T> Borrow for T where
T: ?Sized, [src]
impl<T> Borrow for T where
T: ?Sized, impl<T> BorrowMut for T where
T: ?Sized, [src]
impl<T> BorrowMut for T where
T: ?Sized, fn borrow_mut(&mut self) -> &mut T | [src] |
impl<T, U> TryInto for T where
U: TryFrom<T>, [src]
impl<T, U> TryInto for T where
U: TryFrom<T>, type Error = <U as TryFrom<T>>::Error
🔬 This is a nightly-only experimental API. (
try_from)The type returned in the event of a conversion error.
fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error> | [src] |
impl<T> Any for T where
T: 'static + ?Sized, [src]
impl<T> Any for T where
T: 'static + ?Sized, fn get_type_id(&self) -> TypeId | [src] |
impl<Q, K> Equivalent for Q where
K: Borrow<Q> + ?Sized,
Q: Eq + ?Sized, [src]
impl<Q, K> Equivalent for Q where
K: Borrow<Q> + ?Sized,
Q: Eq + ?Sized, fn equivalent(&self, key: &K) -> bool | [src] |
impl<T> Erased for T
impl<T> Erased for T